@@ -1,6 +1,5 @@
+pub mod address;
 pub mod dhcp_server;
 mod types;
 
-pub use types::*;
-
 const BASE: &str = "rest/ip";
